Shutdown

Enum Shutdown 

1.0.0 ยท Source
pub enum Shutdown {
    Read,
    Write,
    Both,
}
Possible values which can be passed to the TcpStream::shutdown method.

Variants

1.0.0

Read

The reading portion of the TcpStream should be shut down.

All currently blocked and future reads will return Ok(0).

1.0.0

Write

The writing portion of the TcpStream should be shut down.

All currently blocked and future writes will return an error.

1.0.0

Both

Both the reading and the writing portions of the TcpStream should be shut down.

See Shutdown::Read and Shutdown::Write for more information.